@@ -44,13 +44,48 @@ typedef struct _GtkAboutDialog        GtkAboutDialog;
 typedef struct _GtkAboutDialogClass   GtkAboutDialogClass;
 typedef struct _GtkAboutDialogPrivate GtkAboutDialogPrivate;
 
+/**
+ * GtkLicense:
+ * @GTK_LICENSE_UNKNOWN: No license specified
+ * @GTK_LICENSE_CUSTOM: A license text is going to be specified by the
+ *   developer
+ * @GTK_LICENSE_GPL_2_0: The GNU General Public License, version 2.0
+ * @GTK_LICENSE_GPL_3_0: The GNU General Public License, version 3.0
+ * @GTK_LICENSE_LGPL_2_1: The GNU Lesser General Public License, version 2.1
+ * @GTK_LICENSE_LGPL_3_0: The GNU Lesser General Public License, version 3.0
+ * @GTK_LICENSE_BSD: The BSD standard license
+ * @GTK_LICENSE_MIT_X11: The MIT/X11 standard license
+ * @GTK_LICENSE_ARTISTIC: The Artistic License, version 2.0
+ *
+ * The type of license for an application.
+ *
+ * This enumeration can be expanded at later date.
+ *
+ * Since: 3.0
+ */
+typedef enum {
+  GTK_LICENSE_UNKNOWN,
+  GTK_LICENSE_CUSTOM,
+
+  GTK_LICENSE_GPL_2_0,
+  GTK_LICENSE_GPL_3_0,
+
+  GTK_LICENSE_LGPL_2_1,
+  GTK_LICENSE_LGPL_3_0,
+
+  GTK_LICENSE_BSD,
+  GTK_LICENSE_MIT_X11,
+
+  GTK_LICENSE_ARTISTIC
+} GtkLicense;
+
 /**
  * GtkAboutDialog:
  *
  * The <structname>GtkAboutDialog</structname> struct contains
  * only private fields and should not be directly accessed.
  */
-struct _GtkAboutDialog 
+struct _GtkAboutDialog
 {
   GtkDialog parent_instance;
 
@@ -58,10 +93,13 @@ struct _GtkAboutDialog
   GtkAboutDialogPrivate *priv;
 };
 
-struct _GtkAboutDialogClass 
+struct _GtkAboutDialogClass
 {
   GtkDialogClass parent_class;
 
+  gboolean (*activate_link) (GtkAboutDialog *dialog,
+                             const gchar    *uri);
+
   /* Padding for future expansion */
   void (*_gtk_reserved1) (void);
   void (*_gtk_reserved2) (void);
@@ -72,23 +110,26 @@ struct _GtkAboutDialogClass
 GType                  gtk_about_dialog_get_type               (void) G_GNUC_CONST;
 GtkWidget             *gtk_about_dialog_new                    (void);
 void                   gtk_show_about_dialog                   (GtkWindow       *parent,
-								const gchar     *first_property_name,
-								...) G_GNUC_NULL_TERMINATED;
+                                                                const gchar     *first_property_name,
+                                                                ...) G_GNUC_NULL_TERMINATED;
 G_CONST_RETURN gchar  *gtk_about_dialog_get_program_name       (GtkAboutDialog  *about);
 void                   gtk_about_dialog_set_program_name       (GtkAboutDialog  *about,
-								const gchar     *name);
+                                                                const gchar     *name);
 G_CONST_RETURN gchar  *gtk_about_dialog_get_version            (GtkAboutDialog  *about);
 void                   gtk_about_dialog_set_version            (GtkAboutDialog  *about,
-								const gchar     *version);
+                                                                const gchar     *version);
 G_CONST_RETURN gchar  *gtk_about_dialog_get_copyright          (GtkAboutDialog  *about);
 void                   gtk_about_dialog_set_copyright          (GtkAboutDialog  *about,
-								const gchar     *copyright);
+                                                                const gchar     *copyright);
 G_CONST_RETURN gchar  *gtk_about_dialog_get_comments           (GtkAboutDialog  *about);
 void                   gtk_about_dialog_set_comments           (GtkAboutDialog  *about,
-								const gchar     *comments);
+                                                                const gchar     *comments);
 G_CONST_RETURN gchar  *gtk_about_dialog_get_license            (GtkAboutDialog  *about);
 void                   gtk_about_dialog_set_license            (GtkAboutDialog  *about,
-								const gchar     *license);
+                                                                const gchar     *license);
+void                   gtk_about_dialog_set_license_type       (GtkAboutDialog  *about,
+                                                                GtkLicense       license_type);
+GtkLicense             gtk_about_dialog_get_license_type       (GtkAboutDialog  *about);
 
 gboolean               gtk_about_dialog_get_wrap_license       (GtkAboutDialog  *about);
 void                   gtk_about_dialog_set_wrap_license       (GtkAboutDialog  *about,
@@ -96,50 +137,28 @@ void                   gtk_about_dialog_set_wrap_license       (GtkAboutDialog
 
 G_CONST_RETURN gchar  *gtk_about_dialog_get_website            (GtkAboutDialog  *about);
 void                   gtk_about_dialog_set_website            (GtkAboutDialog  *about,
-								const gchar     *website);
+                                                                const gchar     *website);
 G_CONST_RETURN gchar  *gtk_about_dialog_get_website_label      (GtkAboutDialog  *about);
 void                   gtk_about_dialog_set_website_label      (GtkAboutDialog  *about,
-								const gchar     *website_label);
+                                                                const gchar     *website_label);
 G_CONST_RETURN gchar* G_CONST_RETURN * gtk_about_dialog_get_authors            (GtkAboutDialog  *about);
 void                   gtk_about_dialog_set_authors            (GtkAboutDialog  *about,
-								const gchar    **authors);
+                                                                const gchar    **authors);
 G_CONST_RETURN gchar* G_CONST_RETURN * gtk_about_dialog_get_documenters        (GtkAboutDialog  *about);
 void                   gtk_about_dialog_set_documenters        (GtkAboutDialog  *about,
-								const gchar    **documenters);
+                                                                const gchar    **documenters);
 G_CONST_RETURN gchar* G_CONST_RETURN * gtk_about_dialog_get_artists            (GtkAboutDialog  *about);
 void                   gtk_about_dialog_set_artists            (GtkAboutDialog  *about,
-								const gchar    **artists);
+                                                                const gchar    **artists);
 G_CONST_RETURN gchar  *gtk_about_dialog_get_translator_credits (GtkAboutDialog  *about);
 void                   gtk_about_dialog_set_translator_credits (GtkAboutDialog  *about,
-								const gchar     *translator_credits);
+                                                                const gchar     *translator_credits);
 GdkPixbuf             *gtk_about_dialog_get_logo               (GtkAboutDialog  *about);
 void                   gtk_about_dialog_set_logo               (GtkAboutDialog  *about,
-								GdkPixbuf       *logo);
+                                                                GdkPixbuf       *logo);
 G_CONST_RETURN gchar  *gtk_about_dialog_get_logo_icon_name     (GtkAboutDialog  *about);
 void                   gtk_about_dialog_set_logo_icon_name     (GtkAboutDialog  *about,
-								const gchar     *icon_name);
-
-/**
- * GtkAboutDialogActivateLinkFunc:
- * @about: the #GtkAboutDialog in which the link was activated
- * @link_: the URL or email address to which the activated link points
- * @data: user data that was passed when the function was registered
- *  with gtk_about_dialog_set_email_hook() or
- *  gtk_about_dialog_set_url_hook()
- *
- * The type of a function which is called when a URL or email
- * link is activated.
- */
-typedef void (* GtkAboutDialogActivateLinkFunc) (GtkAboutDialog *about,
-						 const gchar    *link_,
-						 gpointer        data);
-
-GtkAboutDialogActivateLinkFunc gtk_about_dialog_set_email_hook (GtkAboutDialogActivateLinkFunc func,
-								gpointer                       data,
-								GDestroyNotify                 destroy);
-GtkAboutDialogActivateLinkFunc gtk_about_dialog_set_url_hook   (GtkAboutDialogActivateLinkFunc func,
-								gpointer                       data,
-								GDestroyNotify                 destroy);
+                                                                const gchar     *icon_name);
 
 G_END_DECLS
 
