@@ -413,6 +413,7 @@ gtk_menu_item_class_init (GtkMenuItemClass *klass)
 static void
 gtk_menu_item_init (GtkMenuItem *menu_item)
 {
+  GtkStyleContext *context;
   GtkMenuItemPrivate *priv;
 
   priv = G_TYPE_INSTANCE_GET_PRIVATE (menu_item,
@@ -437,6 +438,9 @@ gtk_menu_item_init (GtkMenuItem *menu_item)
   priv->use_action_appearance = TRUE;
   priv->timer = 0;
   priv->action = NULL;
+
+  context = gtk_widget_get_style_context (GTK_WIDGET (menu_item));
+  gtk_style_context_add_class (context, GTK_STYLE_CLASS_MENUITEM);
 }
 
 GtkWidget*
@@ -1590,6 +1594,9 @@ gtk_menu_item_draw (GtkWidget *widget,
 
   gtk_style_context_get_padding (context, state, &padding);
 
+  if (GTK_IS_MENU_BAR (parent))
+    gtk_style_context_add_class (context, GTK_STYLE_CLASS_MENUBAR);
+
   if (child && (state & GTK_STATE_FLAG_PRELIGHT))
     {
       gtk_render_background (context, cr, x, y, w, h);
@@ -1746,8 +1753,6 @@ gtk_real_menu_item_activate_item (GtkMenuItem *menu_item)
         gtk_menu_shell_activate_item (menu_shell, widget, TRUE);
       else
         {
-          _gtk_menu_shell_activate (menu_shell);
-
           gtk_menu_shell_select_item (menu_shell, widget);
           _gtk_menu_item_popup_submenu (widget, FALSE);
 
@@ -2564,9 +2569,23 @@ gtk_menu_item_get_use_underline (GtkMenuItem *menu_item)
   return FALSE;
 }
 
+/**
+ * gtk_menu_item_set_reserve_indicator:
+ * @menu_item: a #GtkMenuItem
+ * @reserve: the new value
+ *
+ * Sets whether the @menu_item should reserve space for
+ * the submenu indicator, regardless if it actually has
+ * a submenu or not.
+ *
+ * There should be little need for applications to call
+ * this functions.
+ *
+ * Since: 3.0
+ */
 void
-gtk_menu_item_set_reserve_indicator (GtkMenuItem         *menu_item,
-				     gboolean             reserve)
+gtk_menu_item_set_reserve_indicator (GtkMenuItem *menu_item,
+                                     gboolean     reserve)
 {
   GtkMenuItemPrivate *priv;
 
@@ -2581,8 +2600,21 @@ gtk_menu_item_set_reserve_indicator (GtkMenuItem         *menu_item,
     }
 }
 
+/**
+ * gtk_menu_item_get_reserve_indicator:
+ * @menu_item: a #GtkMenuItem
+ *
+ * Returns whether the @menu_item reserves space for
+ * the submenu indicator, regardless if it has a submenu
+ * or not.
+ *
+ * Returns: %TRUE if @menu_item always reserves space for the
+ *     submenu indicator
+ *
+ * Since: 3.0
+ */
 gboolean
-gtk_menu_item_get_reserve_indicator (GtkMenuItem         *menu_item)
+gtk_menu_item_get_reserve_indicator (GtkMenuItem *menu_item)
 {
   g_return_val_if_fail (GTK_IS_MENU_ITEM (menu_item), FALSE);
 
